@@ -5,10 +5,6 @@ from django.conf.urls.defaults import *
 
 from feedzilla.syndication import PostFeed
 
-feed_dict = {
-    'posts': PostFeed,
-}
-
 urlpatterns = patterns('feedzilla.views',
     url(r'^$', 'index', name='feedzilla_index'),
     url('^tag/(?P<tag_value>.+)$', 'tag', name='feedzilla_tag'),
@@ -18,5 +14,5 @@ urlpatterns = patterns('feedzilla.views',
 )
 
 urlpatterns += patterns('django.contrib.syndication.views',
-    url(r'^feeds/(?P<url>.*)$', 'feed', {'feed_dict': feed_dict}, name='feedzilla_feed'),
+    url(r'^ru/projects/feed$', PostFeed(), name='feedzilla_feed'),
 )
